@@ -8,6 +8,15 @@ use SPVM 'MyMath';
 
 # Initialize SPVM
 
+use strict;
+use warnings;
+use FindBin;
+use lib "$FindBin::Bin/lib";
+use Benchmark qw/timethese cmpthese/;
+
+use SPVM 'MyMath';
+use SPVM 'MyMathPrecompile';
+use SPVM 'MyMathNative';
 
 my $bench_count = 10000;
 my $loop_count = 100000;
@@ -19,10 +28,10 @@ my $result = timethese($bench_count, {
     MyMath->spvm_sum($loop_count);
   },
   spvm_sum_precompile => sub {
-    MyMath->spvm_sum_precompile($loop_count);
+    MyMathPrecompile->spvm_sum($loop_count);
   },
-  spvm_sum_native => sub {
-    MyMath->spvm_sum_native($loop_count);
+  spvm_sum => sub {
+    MyMathNative->spvm_sum($loop_count);
   },
 });
 
