@@ -97,7 +97,7 @@
 
 
 enum {
-  SPVM_OPCODE_C_ID_END_SUB,
+  SPVM_OPCODE_C_ID_END_METHOD,
   SPVM_OPCODE_C_ID_MULNUM_ARRAY_FIELD_FETCH_BYTE,
   SPVM_OPCODE_C_ID_MULNUM_ARRAY_FIELD_FETCH_SHORT,
   SPVM_OPCODE_C_ID_MULNUM_ARRAY_FIELD_FETCH_INT,
@@ -158,20 +158,6 @@ enum {
   SPVM_OPCODE_C_ID_MULNUM_GET_FIELD_LONG,
   SPVM_OPCODE_C_ID_MULNUM_GET_FIELD_FLOAT,
   SPVM_OPCODE_C_ID_MULNUM_GET_FIELD_DOUBLE,
-  SPVM_OPCODE_C_ID_CALL_SUB_VOID,
-  SPVM_OPCODE_C_ID_CALL_SUB_BYTE,
-  SPVM_OPCODE_C_ID_CALL_SUB_SHORT,
-  SPVM_OPCODE_C_ID_CALL_SUB_INT,
-  SPVM_OPCODE_C_ID_CALL_SUB_LONG,
-  SPVM_OPCODE_C_ID_CALL_SUB_FLOAT,
-  SPVM_OPCODE_C_ID_CALL_SUB_DOUBLE,
-  SPVM_OPCODE_C_ID_CALL_SUB_OBJECT,
-  SPVM_OPCODE_C_ID_CALL_SUB_MULNUM_BYTE,
-  SPVM_OPCODE_C_ID_CALL_SUB_MULNUM_SHORT,
-  SPVM_OPCODE_C_ID_CALL_SUB_MULNUM_INT,
-  SPVM_OPCODE_C_ID_CALL_SUB_MULNUM_LONG,
-  SPVM_OPCODE_C_ID_CALL_SUB_MULNUM_FLOAT,
-  SPVM_OPCODE_C_ID_CALL_SUB_MULNUM_DOUBLE,
   SPVM_OPCODE_C_ID_CALL_METHOD_VOID,
   SPVM_OPCODE_C_ID_CALL_METHOD_BYTE,
   SPVM_OPCODE_C_ID_CALL_METHOD_SHORT,
@@ -186,14 +172,28 @@ enum {
   SPVM_OPCODE_C_ID_CALL_METHOD_MULNUM_LONG,
   SPVM_OPCODE_C_ID_CALL_METHOD_MULNUM_FLOAT,
   SPVM_OPCODE_C_ID_CALL_METHOD_MULNUM_DOUBLE,
+  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_VOID,
+  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_BYTE,
+  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_SHORT,
+  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_INT,
+  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_LONG,
+  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_FLOAT,
+  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_DOUBLE,
+  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_OBJECT,
+  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_MULNUM_BYTE,
+  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_MULNUM_SHORT,
+  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_MULNUM_INT,
+  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_MULNUM_LONG,
+  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_MULNUM_FLOAT,
+  SPVM_OPCODE_C_ID_CALL_CALLBACK_METHOD_MULNUM_DOUBLE,
   SPVM_OPCODE_C_ID_ADD_INT,
   SPVM_OPCODE_C_ID_ADD_LONG,
   SPVM_OPCODE_C_ID_ADD_FLOAT,
   SPVM_OPCODE_C_ID_ADD_DOUBLE,
-  SPVM_OPCODE_C_ID_SUBTRACT_INT,
-  SPVM_OPCODE_C_ID_SUBTRACT_LONG,
-  SPVM_OPCODE_C_ID_SUBTRACT_FLOAT,
-  SPVM_OPCODE_C_ID_SUBTRACT_DOUBLE,
+  SPVM_OPCODE_C_ID_METHODTRACT_INT,
+  SPVM_OPCODE_C_ID_METHODTRACT_LONG,
+  SPVM_OPCODE_C_ID_METHODTRACT_FLOAT,
+  SPVM_OPCODE_C_ID_METHODTRACT_DOUBLE,
   SPVM_OPCODE_C_ID_MULTIPLY_INT,
   SPVM_OPCODE_C_ID_MULTIPLY_LONG,
   SPVM_OPCODE_C_ID_MULTIPLY_FLOAT,
